# -*- coding: UTF-8 -*-
# Copyright 2013-2016 Luc Saffre
# License: GNU Affero General Public License v3 (see file COPYING for details)

"""Database models for :mod:`lino_welfare.modlib.users`.

"""

from lino.modlib.users.models import *



from .ui import *
