# -*- coding: UTF-8 -*-
# Copyright 2014-2018 Rumma & Ko Ltd
# License: GNU Affero General Public License v3 (see file COPYING for details)
"""
The main plugin for Lino Amici.

.. autosummary::
   :toctree:

    user_types
    workflows

"""

from lino.api.ad import Plugin


class Plugin(Plugin):
    pass

